==> httraqt_1.2.0.orig.tar.gz: httraqt/sources/main/includes/FinalTab.h <==
/***************************************************************************
 * C++ Implementation:                                                     *
 * Copyright (C) 2012-2013 by Eduard Kalinowski                            *
 * Germany, Lower Saxony, Hanover                                          *
 * eduard_kalinowski@yahoo.de                                              *
 *                                                                         *
 * HTTraQt is free software; you can redistribute it and/or                *
 * modify it under the terms of the GNU Lesser General Public              *
 * License as published by the Free Software Foundation; either            *
 * version 3 of the License, or (at your option) any later version.        *
 *                                                                         *
 * HTTraQt is distributed in the hope that it will be useful, but          *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
 *                                                                         *
 * See the GNU Lesser General Public License for more details.             *
 *                                                                         *
 * You should have received a copy of the GNU Lesser General Public        *
 * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
 ***************************************************************************/

#ifndef FINWIDGET_H
#define FINWIDGET_H

#include <qwidget.h>
#include "ui_FinalTab.h"


class HTTraQt;

class FinalTab: public QWidget, public Ui_FinalTab
{
        Q_OBJECT
    public:
        FinalTab(QWidget *parent = 0, Qt::WFlags fl = 0);
    public slots:
        void translate(void);
    private slots:
        void onBrowseLocalWebsite();
        void onViewLog();

    private:
        HTTraQt* parent;
};

#endif

==> httraqt_1.3.0.orig.tar.gz: httraqt/sources/main/includes/FinalTab.h <==
/***************************************************************************
 * C++ Implementation:                                                     *
 * Copyright (C) 2012-2014 by Eduard Kalinowski                            *
 * Germany, Lower Saxony, Hanover                                          *
 * eduard_kalinowski@yahoo.de                                              *
 *                                                                         *
 * HTTraQt is free software; you can redistribute it and/or                *
 * modify it under the terms of the GNU Lesser General Public              *
 * License as published by the Free Software Foundation; either            *
 * version 3 of the License, or (at your option) any later version.        *
 *                                                                         *
 * HTTraQt is distributed in the hope that it will be useful, but          *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
 *                                                                         *
 * See the GNU Lesser General Public License for more details.             *
 *                                                                         *
 * You should have received a copy of the GNU Lesser General Public        *
 * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
 ***************************************************************************/

#ifndef FINWIDGET_H
#define FINWIDGET_H

#include <QWidget>

#include "httraqt.h"
#include "ui_FinalTab.h"


class HTTraQt;

class FinalTab: public QWidget, public Ui_FinalTab, public Translator
{
        Q_OBJECT
    public:
        FinalTab(QWidget *parent = 0, Qt::WindowFlags fl = 0);
    public slots:
        void translateTab(void);
    private slots:
        void onBrowseLocalWebsite();
        void onViewLog();

    private:
        HTTraQt* parent;
};

#endif
